-- 商品模块
CREATE TABLE product_category (
    category_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    category_name VARCHAR(50) NOT NULL COMMENT '五金/水电/建材',
    parent_id INT UNSIGNED DEFAULT NULL,
    specifications JSON COMMENT '规格模板',
    lft INT UNSIGNED NOT NULL COMMENT '嵌套集合左值',
    rgt INT UNSIGNED NOT NULL COMMENT '嵌套集合右值',
    INDEX idx_nested_set (lft, rgt)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

CREATE TABLE products (
    product_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    sku VARCHAR(24) NOT NULL UNIQUE,
    category_id INT UNSIGNED NOT NULL,
    brand VARCHAR(50),
    model VARCHAR(50) COMMENT '型号',
    material VARCHAR(50) COMMENT '材质',
    barcode VARCHAR(30) UNIQUE,
    unit_price DECIMAL(10, 2) NOT NULL,
    safety_stock INT NOT NULL DEFAULT 0 COMMENT '安全库存',
    specifications JSON NOT NULL COMMENT '动态规格',
    expiry_control BOOLEAN DEFAULT FALSE COMMENT '是否启用保质期',
    FOREIGN KEY (category_id) REFERENCES product_category(category_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 库存模块
CREATE TABLE warehouse (
    warehouse_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    warehouse_name VARCHAR(50) NOT NULL,
    type ENUM('总仓', '区域仓', '门店仓') NOT NULL,
    address VARCHAR(255),
    contact_phone VARCHAR(20)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

CREATE TABLE inventory (
    inventory_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    product_id BIGINT UNSIGNED NOT NULL,
    warehouse_id INT UNSIGNED NOT NULL,
    batch_no VARCHAR(20) NOT NULL COMMENT '批次号',
    quantity INT NOT NULL DEFAULT 0,
    production_date DATE COMMENT '生产日期',
    expiry_date DATE COMMENT '过期日期',
    cost_price DECIMAL(10, 2) NOT NULL,
    last_sync TIMESTAMP NULL COMMENT '多仓同步时间',
    UNIQUE KEY uniq_stock (product_id, warehouse_id, batch_no),
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    FOREIGN KEY (warehouse_id) REFERENCES warehouse(warehouse_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 采购模块
CREATE TABLE supplier (
    supplier_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    supplier_name VARCHAR(100) NOT NULL,
    contact_person VARCHAR(50),
    rating TINYINT UNSIGNED COMMENT '供应商评分(1-5)',
    payment_terms VARCHAR(255) COMMENT '付款条件'
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

CREATE TABLE purchase_order (
    po_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    supplier_id INT UNSIGNED NOT NULL,
    order_no VARCHAR(20) NOT NULL UNIQUE,
    total_amount DECIMAL(12, 2) NOT NULL,
    status ENUM('待审批', '已批准', '已完成', '已取消') NOT NULL,
    expected_delivery DATE,
    actual_delivery DATE,
    created_by INT UNSIGNED NOT NULL COMMENT '操作人员',
    FOREIGN KEY (supplier_id) REFERENCES supplier(supplier_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 销售模块
CREATE TABLE sales_order (
    order_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    order_no VARCHAR(24) NOT NULL UNIQUE COMMENT '订单号规则:SO+日期+序列',
    customer_id INT UNSIGNED NOT NULL,
    total_amount DECIMAL(12, 2) NOT NULL,
    payment_method ENUM('现金', '支付宝', '微信', '银行卡', '赊账') NOT NULL,
    order_type ENUM('零售', '批发', '线上') NOT NULL,
    store_id INT UNSIGNED COMMENT '门店ID',
    salesperson_id INT UNSIGNED NOT NULL,
    delivery_status ENUM('待出库', '配送中', '已签收') NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    INDEX idx_order_date (created_at)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 会员与客户
CREATE TABLE customer (
    customer_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    customer_type ENUM('零售客户', '批发客户', '会员') NOT NULL,
    customer_name VARCHAR(100) NOT NULL,
    phone VARCHAR(20) NOT NULL UNIQUE,
    credit_limit DECIMAL(10, 2) DEFAULT 0 COMMENT '信用额度',
    membership_level TINYINT UNSIGNED COMMENT '会员等级',
    accumulated_points INT UNSIGNED DEFAULT 0
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 零售客户示例（无信用额度和会员等级）
INSERT INTO customer (
    customer_type,
    customer_name,
    phone,
    credit_limit,
    membership_level,
    accumulated_points
) VALUES (
    '零售客户',
    '张伟',
    '13812345678',
    DEFAULT(credit_limit),  -- 使用默认值0
    NULL,
    0
);

-- 批发客户示例（有信用额度，无会员等级）
INSERT INTO customer (
    customer_type,
    customer_name,
    phone,
    credit_limit,
    membership_level,
    accumulated_points
) VALUES (
    '批发客户',
    '李强',
    '13987654321',
    10000.00,
    NULL,
    0
);

-- 会员客户示例（有信用额度和会员等级）
INSERT INTO customer (
    customer_type,
    customer_name,
    phone,
    credit_limit,
    membership_level,
    accumulated_points
) VALUES (
    '会员',
    '王芳',
    '13698765432',
    5000.00,
    5,
    5000
);

-- 财务模块
CREATE TABLE financial_transaction (
    transaction_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    order_id BIGINT UNSIGNED NOT NULL,
    amount DECIMAL(12, 2) NOT NULL,
    transaction_type ENUM('收入', '支出', '退款','应收款') NOT NULL,
    payment_channel VARCHAR(50),
    invoice_no VARCHAR(20) COMMENT '发票号',
    transaction_time DATETIME NOT NULL,
    FOREIGN KEY (order_id) REFERENCES sales_order(order_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 多门店管理
CREATE TABLE store (
    store_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    store_name VARCHAR(100) NOT NULL,
    warehouse_id INT UNSIGNED NOT NULL COMMENT '关联仓库',
    manager_id INT UNSIGNED NOT NULL,
    sales_target DECIMAL(12, 2) COMMENT '销售目标',
    FOREIGN KEY (warehouse_id) REFERENCES warehouse(warehouse_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 售后与设备
CREATE TABLE service_order (
    service_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    order_id BIGINT UNSIGNED NOT NULL,
    technician_id INT UNSIGNED NOT NULL,
    service_type ENUM('安装', '维修', '保养') NOT NULL,
    scheduled_time DATETIME NOT NULL,
    completed_time DATETIME,
    service_status ENUM('待处理', '进行中', '已完成') NOT NULL,
    FOREIGN KEY (order_id) REFERENCES sales_order(order_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 系统管理
CREATE TABLE system_user (
    user_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    username VARCHAR(50) NOT NULL UNIQUE,
    password_hash VARCHAR(255) NOT NULL,
    role ENUM(
        'admin',
        'store_manager',
        'sales',
        'finance',
        'logistics'
    ) NOT NULL,
    store_id INT UNSIGNED COMMENT '所属门店',
    last_login DATETIME
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 中间关联表
CREATE TABLE order_item (
    order_id BIGINT UNSIGNED NOT NULL,
    product_id BIGINT UNSIGNED NOT NULL,
    quantity INT NOT NULL,
    unit_price DECIMAL(10, 2) NOT NULL,
    batch_no VARCHAR(20) NOT NULL COMMENT '出库批次',
    PRIMARY KEY (order_id, product_id, batch_no),
    FOREIGN KEY (order_id) REFERENCES sales_order(order_id),
    FOREIGN KEY (product_id) REFERENCES products(product_id)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

CREATE TABLE promotion (
    promo_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    promo_type ENUM('满减', '折扣', '赠品') NOT NULL,
    condition_amount DECIMAL(10, 2) COMMENT '满足金额',
    discount_rate DECIMAL(5, 2) COMMENT '折扣率',
    start_date DATE NOT NULL,
    end_date DATE NOT NULL,
    applicable_products JSON COMMENT '适用商品ID数组'
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;

-- 创建备份日志表
CREATE TABLE backup_log (
    log_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    filename VARCHAR(255) NOT NULL,
    file_size INT UNSIGNED NOT NULL,
    backup_time DATETIME DEFAULT CURRENT_TIMESTAMP,
    operator_id INT UNSIGNED NOT NULL,
    FOREIGN KEY (operator_id) REFERENCES system_user(user_id)
);

-- 添加库存调拨功能
CREATE TABLE inventory_transfer (
    transfer_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    product_id BIGINT UNSIGNED NOT NULL,
    from_store INT UNSIGNED NOT NULL,
    to_store INT UNSIGNED NOT NULL,
    quantity INT UNSIGNED NOT NULL,
    transfer_time DATETIME DEFAULT CURRENT_TIMESTAMP,
    operator_id INT UNSIGNED NOT NULL,
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    FOREIGN KEY (from_store) REFERENCES store(store_id),
    FOREIGN KEY (to_store) REFERENCES store(store_id)
);

-- 添加门店管理索引
ALTER TABLE store ADD INDEX idx_managed (manager_id);

-- 满200元减50元，适用于商品ID为1和2的商品
INSERT INTO promotion (
    promo_type, 
    condition_amount, 
    discount_rate, 
    start_date, 
    end_date, 
    applicable_products
) VALUES (
    '满减',
    200.00,
    50.00,
    '2024-01-01',
    '2024-12-31',
    JSON_ARRAY(1,2)
);



-- 索引优化
ALTER TABLE
    inventory
ADD
    INDEX idx_expiry (expiry_date);

ALTER TABLE
    sales_order
ADD
    INDEX idx_customer (customer_id);

ALTER TABLE
    products
ADD
    FULLTEXT INDEX idx_product_search (brand, model);


-- 添加系统管理员（使用PHP password_hash加密）
INSERT INTO system_user (username, password_hash, role, store_id, last_login)
VALUES (
    'admin',
    '$2y$10$7DOsBGGPYLrOYejhj07BbOmC4pq1gFp0qImybWTD4iX3pVnaACUMa', -- 密码admin的哈希值
    'admin',
    1,
    NOW()
);

-- 添加默认店员
INSERT INTO system_user (username, password_hash, role, store_id)
VALUES ('default_sales', '$2y$10$92IXUNpkjO0rOQ5byMi.Ye4oKoEa3Ro9llC/.og/at2.uheWG/igi', 'sales', 1);
-- 密码为password

-- 添加权限配置数据
CREATE TABLE IF NOT EXISTS user_privileges (
    privilege_id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    user_id INT UNSIGNED NOT NULL,
    module ENUM('商品','采购','销售','财务','报表') NOT NULL,
    permission_level ENUM('只读','编辑','管理') NOT NULL,
    FOREIGN KEY (user_id) REFERENCES system_user(user_id)
);


-- 插入商品管理权限
INSERT INTO user_privileges (user_id, module, permission_level)
SELECT user_id, '商品', '管理' 
FROM system_user 
WHERE username = 'admin';

-- 插入采购管理权限
INSERT INTO user_privileges (user_id, module, permission_level)
SELECT user_id, '采购', '管理' 
FROM system_user 
WHERE username = 'admin';

-- 插入销售管理权限
INSERT INTO user_privileges (user_id, module, permission_level)
SELECT user_id, '销售', '管理' 
FROM system_user 
WHERE username = 'admin';

-- 插入财务管理权限
INSERT INTO user_privileges (user_id, module, permission_level)
SELECT user_id, '财务', '管理' 
FROM system_user 
WHERE username = 'admin';

-- 插入报表管理权限
INSERT INTO user_privileges (user_id, module, permission_level)
SELECT user_id, '报表', '管理' 
FROM system_user 
WHERE username = 'admin';

-- 插入顶级分类
INSERT INTO product_category (category_name, parent_id, specifications, lft, rgt) VALUES
('五金', NULL, '{"品牌": "", "型号": "", "材质": ""}', 1, 8),
('水电', NULL, '{"品牌": "", "型号": "", "材质": ""}', 9, 16),
('建材', NULL, '{"品牌": "", "型号": "", "材质": ""}', 17, 22);

-- 获取自动生成的分类ID
SET @hardware_id = LAST_INSERT_ID();
SET @plumbing_id = @hardware_id + 1;
SET @building_id = @hardware_id + 2;

-- 插入五金类子分类
INSERT INTO product_category (category_name, parent_id, specifications, lft, rgt) VALUES
('水管', @hardware_id, '{"品牌": "通用", "型号": "DN20", "材质": "PPR"}', 2, 3),
('阀门', @hardware_id, '{"品牌": "通用", "型号": "DN25", "材质": "铜"}', 4, 5),
('螺丝', @hardware_id, '{"品牌": "通用", "型号": "M6", "材质": "不锈钢"}', 6, 7);

-- 插入水电类子分类
INSERT INTO product_category (category_name, parent_id, specifications, lft, rgt) VALUES
('电线', @plumbing_id, '{"品牌": "国标", "型号": "2.5mm²", "材质": "铜芯"}', 10, 11),
('电表', @plumbing_id, '{"品牌": "智能", "型号": "DDS28", "材质": "工程塑料"}', 12, 13),
('照明', @plumbing_id, '{"品牌": "LED", "型号": "18W", "材质": "铝合金"}', 14, 15);

-- 插入建材类子分类
INSERT INTO product_category (category_name, parent_id, specifications, lft, rgt) VALUES
('涂料', @building_id, '{"品牌": "环保", "型号": "乳胶漆", "材质": "水性"}', 18, 19),
('砖瓦', @building_id, '{"品牌": "红狮", "型号": "标准砖", "材质": "粘土"}', 20, 21);

-- 开启事务保证原子性
START TRANSACTION;

-- 插入顶级分类（确保唯一性）
INSERT IGNORE INTO product_category 
    (category_name, specifications, lft, rgt)
VALUES
    ('五金', '{"类型":"基础材料"}', 1, 8),
    ('水电', '{"类型":"水电材料"}', 9, 16),
    ('建材', '{"类型":"建筑辅材"}', 17, 24);

-- 获取五金分类ID
SET @hardware_id = (SELECT category_id FROM product_category 
                   WHERE category_name = '五金' AND parent_id IS NULL
                   LIMIT 1);

-- 插入水管子分类（正确嵌套集合参数）
INSERT INTO product_category 
    (category_name, parent_id, specifications, lft, rgt)
VALUES
    ('PPR水管', @hardware_id, '{"直径":"20mm"}', 2, 3),
    ('铜阀门', @hardware_id, '{"规格":"DN25"}', 4, 5);

-- 插入水电产品（带完整规格）
INSERT INTO products (
    sku, category_id, brand, model, 
    material, barcode, unit_price, 
    safety_stock, specifications, expiry_control
) SELECT 
    'WH-PPR20',
    pc.category_id,
    '测试',
    'S3.2',
    'PPR',
    '6931234567891',
    12.80,
    500,
    '{"长度":"4m","耐温":"95℃"}',
    TRUE
FROM product_category pc
WHERE pc.category_name = 'PPR水管'
  AND pc.parent_id = @hardware_id
LIMIT 1;

-- 创建华东区域仓（唯一名称）
INSERT IGNORE INTO warehouse 
    (warehouse_name, type, address)
VALUES
    ('华东总仓', '总仓', '上海浦东物流园'),
    ('南京分仓', '区域仓', '南京江宁物流园');

-- 插入库存记录（带事务保护）
INSERT INTO inventory (
    product_id, warehouse_id, batch_no,
    quantity, production_date, expiry_date,
    cost_price, last_sync
) SELECT 
    (SELECT product_id FROM products WHERE sku = 'WH-PPR20' LIMIT 1),
    (SELECT warehouse_id FROM warehouse WHERE warehouse_name = '华东总仓' LIMIT 1),
    'B20231001',
    1500,
    '2023-10-01',
    '2025-10-01',
    9.80,
    NOW()
FROM DUAL
WHERE EXISTS (
    SELECT 1 FROM products WHERE sku = 'WH-PPR20'
) AND EXISTS (
    SELECT 1 FROM warehouse WHERE warehouse_name = '华东总仓'
);

-- 提交事务
COMMIT;

-- 验证库存记录
SELECT 
    p.sku AS 产品编码,
    w.warehouse_name AS 仓库,
    i.quantity AS 库存量,
    i.batch_no AS 批次,
    DATEDIFF(i.expiry_date, CURDATE()) AS 剩余保质期
FROM inventory i
JOIN products p USING (product_id)
JOIN warehouse w USING (warehouse_id)
WHERE p.sku = 'WH-PPR20';

/* 预期输出：
+--------------+-----------+-----------+--------+-----------------+
| 产品编码     | 仓库      | 库存量    | 批次   | 剩余保质期      |
+--------------+-----------+-----------+--------+-----------------+
| WH-PPR20     | 华东总仓  | 1500      |B20231001| 730            |
+--------------+-----------+-----------+--------+-----------------+
*/

-- 新增采购订单明细表
CREATE TABLE purchase_order_item (
    item_id BIGINT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    po_id BIGINT UNSIGNED NOT NULL,
    product_id BIGINT UNSIGNED NOT NULL,
    quantity INT UNSIGNED NOT NULL,
    unit_price DECIMAL(10,2) NOT NULL,
    FOREIGN KEY (po_id) REFERENCES purchase_order(po_id),
    FOREIGN KEY (product_id) REFERENCES products(product_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;

-- 添加索引优化查询
ALTER TABLE purchase_order_item
ADD INDEX idx_po_product (po_id, product_id);


START TRANSACTION;
-- 插入供应商示例（确保基础数据存在）
INSERT IGNORE INTO supplier (
    supplier_name, 
    contact_person, 
    rating, 
    payment_terms
) VALUES
('伟星建材', '张经理', 5, '货到付款'),
('联塑管道', '李主管', 4, '月结30天');

-- 验证供应商数据
SET @supplier_id = (SELECT supplier_id FROM supplier WHERE supplier_name = '伟星建材' LIMIT 1);

-- 插入采购订单头
INSERT INTO purchase_order (
    supplier_id,
    order_no,
    total_amount,
    status,
    created_by
) VALUES (
    @supplier_id,
    'PO20231001',
    15000.00,
    '已完成',
    (SELECT user_id FROM system_user WHERE username = 'admin' LIMIT 1)
);

-- 获取生成的订单ID
SET @po_id = LAST_INSERT_ID();

-- 关联产品（确保产品存在）
INSERT INTO purchase_order_item (
    po_id,
    product_id,
    quantity,
    unit_price
) SELECT 
    @po_id,
    p.product_id,
    200,
    p.unit_price * 0.9
FROM products p
WHERE p.sku = 'WH-PPR20'
LIMIT 1;  -- 确保唯一匹配
COMMIT;

-- 添加仓库示例
INSERT INTO warehouse (warehouse_name, type, address) VALUES
('上海浦东总仓', '总仓', '浦东新区物流园1号'),
('南京路门店仓', '门店仓', '上海市南京路100号');

-- 添加门店示例（关联仓库）
INSERT INTO store (store_name, warehouse_id, manager_id) VALUES
('南京路旗舰店', 
 (SELECT warehouse_id FROM warehouse WHERE warehouse_name = '南京路门店仓'),
 (SELECT user_id FROM system_user WHERE username = 'admin')
);

-- 添加商品库存示例
INSERT INTO inventory (product_id, warehouse_id, batch_no, quantity, cost_price) VALUES
((SELECT product_id FROM products WHERE sku = 'WH-PPR20'), 
 (SELECT warehouse_id FROM warehouse WHERE warehouse_name = '南京路门店仓'),
 'B20240101', 100, 10.50);

-- 添加默认日销售额
INSERT INTO sales_order (order_no, customer_id, total_amount, payment_method, order_type, salesperson_id, store_id, created_at)
VALUES ('SO20231001', 1, 1000.00, '现金', '零售', 1, 1, '2025-3-04 12:00:00');

