<!-- 库存管理 -->

<?php
// inventory.php
require_once '../config.php';
// check_login();

// 处理库存调拨
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $pdo->beginTransaction();

        // 减少调出仓库存
        $stmt = $pdo->prepare("
            UPDATE inventory 
            SET quantity = quantity - :quantity,
                last_sync = NOW()
            WHERE inventory_id = :from_id
        ");
        $stmt->execute([
            ':quantity' => $_POST['quantity'],
            ':from_id' => $_POST['from_id']
        ]);

        // 增加调入仓库存
        $stmt = $pdo->prepare("
            INSERT INTO inventory (
                product_id, warehouse_id, batch_no, quantity, 
                production_date, expiry_date, cost_price, last_sync
            ) VALUES (
                :product_id, :warehouse_id, :batch_no, :quantity,
                :production_date, :expiry_date, :cost_price, NOW()
            )
            ON DUPLICATE KEY UPDATE 
                quantity = quantity + VALUES(quantity),
                last_sync = NOW()
        ");
        $stmt->execute([
            ':product_id' => $_POST['product_id'],
            ':warehouse_id' => $_POST['to_warehouse'],
            ':batch_no' => $_POST['batch_no'],
            ':quantity' => $_POST['quantity'],
            ':production_date' => $_POST['production_date'],
            ':expiry_date' => $_POST['expiry_date'],
            ':cost_price' => $_POST['cost_price']
        ]);

        $pdo->commit();
        header("Location: inventory.php?success=1");
        exit;
    } catch (PDOException $e) {
        $pdo->rollBack();
        die("操作失败: " . $e->getMessage());
    }
}

// 获取数据
$warehouses = $pdo->query("SELECT * FROM warehouse")->fetchAll();
$inventory = $pdo->query("
    SELECT 
        i.*,
        p.brand,
        p.model,
        p.sku,
        p.safety_stock,
        p.expiry_control,
        w.warehouse_name,
        w.type AS warehouse_type,
        DATEDIFF(i.expiry_date, CURDATE()) AS days_remaining,
        TIMESTAMPDIFF(HOUR, i.last_sync, NOW()) AS sync_hours
    FROM inventory i
    JOIN products p ON i.product_id = p.product_id
    JOIN warehouse w ON i.warehouse_id = w.warehouse_id
    ORDER BY i.expiry_date
")->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <title>库存管理系统</title>
    <link rel="stylesheet" href="./style.css">
    <style>        
        /* 库存特定样式 */
        .stock-indicator {
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .progress-bar {
            width: 120px;
            height: 8px;
            background: #eee;
            border-radius: 4px;
            overflow: hidden;
        }

        .progress-fill {
            height: 100%;
            background: #3498db;
            transition: width 0.3s;
        }

        .status-dot {
            width: 12px;
            height: 12px;
            border-radius: 50%;
            display: inline-block;
        }

        .safe {
            background: #2ecc71;
        }

        .warning {
            background: #f1c40f;
        }

        .expired {
            background: #e74c3c;
        }

        .low-stock {
            background-color: #ffeef0;
        }

        .sync-status {
            font-size: 0.9em;
            color: #666;
        }
    </style>
</head>

<body>

    <div class="content-frame">
        <div class="container">
            <h2>库存管理</h2>

            <!-- 调拨操作表单 -->
            <div class="form-container">
                <form method="post">
                    <div class="form-group">
                        <label>选择调出库存：</label>
                        <select name="from_id" required>
                            <?php foreach ($inventory as $item): ?>
                                <option value="<?= $item['inventory_id'] ?>">
                                    <?= $item['brand'] ?> <?= $item['model'] ?>
                                    - <?= $item['warehouse_name'] ?> (剩余:<?= $item['quantity'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>调拨数量：</label>
                        <input type="number" name="quantity" required min="1">
                    </div>

                    <div class="form-group">
                        <label>目标仓库：</label>
                        <select name="to_warehouse" required>
                            <?php foreach ($warehouses as $wh): ?>
                                <option value="<?= $wh['warehouse_id'] ?>">
                                    <?= $wh['warehouse_name'] ?> (<?= $wh['type'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <input type="hidden" name="product_id" value="<?= $inventory[0]['product_id'] ?>">
                    <input type="hidden" name="batch_no" value="<?= $inventory[0]['batch_no'] ?>">
                    <input type="hidden" name="production_date" value="<?= $inventory[0]['production_date'] ?>">
                    <input type="hidden" name="expiry_date" value="<?= $inventory[0]['expiry_date'] ?>">
                    <input type="hidden" name="cost_price" value="<?= $inventory[0]['cost_price'] ?>">

                    <button type="submit" class="btn-primary">执行调拨</button>
                </form>
            </div>

            <!-- 库存清单表格 -->
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>商品信息</th>
                            <th>仓库</th>
                            <th>库存状态</th>
                            <th>批次信息</th>
                            <th>最后同步</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inventory as $item): ?>
                            <tr class="<?= $item['quantity'] < $item['safety_stock'] ? 'low-stock' : '' ?>">
                                <td>
                                    <div class="product-info">
                                        <strong><?= $item['brand'] ?> <?= $item['model'] ?></strong>
                                        <div>SKU: <?= $item['sku'] ?></div>
                                    </div>
                                </td>
                                <td>
                                    <?= $item['warehouse_name'] ?>
                                    <div class="warehouse-type">(<?= $item['warehouse_type'] ?>)</div>
                                </td>
                                <td>
                                    <div class="stock-indicator">
                                        <div class="progress-bar">
                                            <div class="progress-fill"
                                                style="width: <?= min(100, ($item['quantity'] / $item['safety_stock']) * 100) ?>%"></div>
                                        </div>
                                        <span><?= $item['quantity'] ?>/<?= $item['safety_stock'] ?></span>
                                    </div>
                                </td>
                                <td>
                                    <?php if ($item['expiry_control']): ?>
                                        <div class="batch-info">
                                            <div>批次: <?= $item['batch_no'] ?></div>
                                            <div class="expiry-status">
                                                <span class="status-dot <?=
                                                                        $item['days_remaining'] < 0 ? 'expired' : ($item['days_remaining'] < 30 ? 'warning' : 'safe') ?>"></span>
                                                <?= $item['days_remaining'] >= 0 ? $item['days_remaining'] . '天' : '已过期' ?>
                                            </div>
                                            <div class="date-range">
                                                <?= $item['production_date'] ?> ~ <?= $item['expiry_date'] ?>
                                            </div>
                                        </div>
                                    <?php else: ?>
                                        <div>无需保质期管理</div>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?= $item['last_sync'] ?>
                                    <div class="sync-status">
                                        (<?= $item['sync_hours'] ?>小时前同步)
                                    </div>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>