<?php
session_start();
require '../config.php';

// 处理销售订单
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $barcode = $_POST['barcode'];
    $quantity = (int)$_POST['quantity'];
    $paymentMethod = $_POST['payment_method'];

    try {
        $pdo->beginTransaction();

        // 获取商品信息
        $product = $pdo->prepare("
            SELECT p.product_id, p.unit_price, i.quantity AS stock
            FROM products p
            JOIN inventory i USING(product_id)
            WHERE p.barcode = ? AND i.warehouse_id = (
                SELECT warehouse_id FROM store WHERE store_id = ?
            )
        ");
        $product->execute([$barcode, $_SESSION['store_id']]);
        $product = $product->fetch();

        if (!$product || $product['stock'] < $quantity) {
            throw new Exception("商品库存不足或不存在");
        }

        // 创建销售订单
        $orderNo = 'SO' . date('YmdHis');
        // 检查门店ID
        if (empty($_SESSION['store_id'])) {
            throw new Exception("当前用户未关联有效门店");
        }

        $stmt = $pdo->prepare("
    INSERT INTO sales_order 
    (order_no, customer_id, total_amount, payment_method, order_type, salesperson_id, delivery_status, store_id)
    VALUES (?, 0, ?, ?, '零售', ?, '已签收', ?)
");
        $total = $product['unit_price'] * $quantity;
        
        $stmt->execute([$orderNo, $total, $paymentMethod, $_SESSION['user_id'], $_SESSION['store_id']]);
        $orderId = $pdo->lastInsertId();

        // 添加订单明细
        $stmt = $pdo->prepare("
            INSERT INTO order_item 
            (order_id, product_id, quantity, unit_price, batch_no)
            VALUES (?, ?, ?, ?, (
                SELECT batch_no FROM inventory 
                WHERE product_id = ? 
                ORDER BY expiry_date ASC 
                LIMIT 1
            ))
        ");
        $stmt->execute([$orderId, $product['product_id'], $quantity, $product['unit_price'], $product['product_id']]);

        // 记录财务交易
        $stmt = $pdo->prepare("
            INSERT INTO financial_transaction 
            (order_id, amount, transaction_type, payment_channel, transaction_time)
            VALUES (?, ?, '收入', ?, NOW())
        ");
        $stmt->execute([$orderId, $total, $paymentMethod]);

        $pdo->commit();
        $success = "销售成功！订单号：{$orderNo}";
    } catch (Exception $e) {
        $pdo->rollBack();
        $error = $e->getMessage();
    }
}
// 新增：获取当前门店的仓库ID
$storeId = $_SESSION['store_id'] ?? 0;
$warehouseId = $pdo->prepare("
    SELECT warehouse_id FROM store WHERE store_id = ?
");
$warehouseId->execute([$storeId]);
$warehouseId = $warehouseId->fetchColumn();


// 新增：获取有库存的商品列表
$products = $pdo->prepare("
    SELECT p.barcode, p.model, p.sku, i.quantity 
    FROM products p
    JOIN inventory i USING(product_id)
    WHERE i.warehouse_id = ? AND i.quantity > 0
    ORDER BY p.model
");
$products->execute([$warehouseId]);
$productList = $products->fetchAll();

// 新增：获取当前门店历史订单
$history = $pdo->prepare("
    SELECT s.order_no, s.created_at, s.total_amount, s.payment_method,
           COUNT(oi.product_id) AS items, 
           GROUP_CONCAT(p.model SEPARATOR ', ') AS products
    FROM sales_order s
    JOIN order_item oi USING(order_id)
    JOIN products p USING(product_id)
    WHERE s.store_id = ?
    GROUP BY s.order_id
    ORDER BY s.created_at DESC
    LIMIT 10
");
$history->execute([$_SESSION['store_id']]);
$orders = $history->fetchAll();
// echo $_SESSION['store_id'];
?>
<!DOCTYPE html>
<html>

<head>
    <title>零售销售</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 继承全局样式 */
        .container {
            max-width: 800px;
            margin: 20px auto;
            padding: 20px;
        }

        .scan-box {
            border: 2px dashed #ccc;
            padding: 20px;
            text-align: center;
            margin-bottom: 20px;
        }

        .receipt-preview {
            background: #fff;
            padding: 15px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        /* 新增下拉菜单样式（保持原有风格） */
        .barcode-select {
            width: 100%;
            padding: 10px;
            border: 1px solid #ccc;
            border-radius: 4px;
            margin: 10px 0;
        }

        .stock-info {
            color: #666;
            font-size: 0.9em;
            margin-top: 5px;
        }

        .sales-history {
            margin-top: 40px;
            border-top: 2px solid #eee;
            padding-top: 20px;
        }

        .sales-history table {
            width: 100%;
            border-collapse: collapse;
        }

        .sales-history th {
            background-color: #f5f5f5;
        }

        .sales-history th,
        .sales-history td {
            padding: 12px;
            border-bottom: 1px solid #ddd;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>零售收银台</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <?php if (isset($success)): ?>
            <div class="alert alert-success"><?= $success ?></div>
        <?php endif; ?>

        <div class="form-container">
            <form method="POST">
                <div class="scan-box">
                    <label>选择商品</label>
                    <select name="barcode" class="barcode-select" required>
                        <option value="">请选择商品</option>
                        <?php foreach ($productList as $product): ?>
                            <option value="<?= $product['barcode'] ?>">
                                <?= $product['model'] ?> (<?= $product['sku'] ?>)
                                - 库存: <?= $product['quantity'] ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>购买数量</label>
                    <input type="number" name="quantity" min="1" value="1" required>
                </div>

                <div class="form-group">
                    <label>支付方式</label>
                    <select name="payment_method" required>
                        <option value="现金">现金</option>
                        <option value="支付宝">支付宝</option>
                        <option value="微信">微信</option>
                    </select>
                </div>

                <button type="submit" class="btn-primary">确认收款</button>
            </form>
        </div>
        <div class="sales-history">
            <h3>最近10笔订单</h3>
            <table>
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>时间</th>
                        <th>金额</th>
                        <th>商品数</th>
                        <th>支付方式</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td><?= htmlspecialchars($order['order_no']) ?></td>
                            <td><?= date('m-d H:i', strtotime($order['created_at'])) ?></td>
                            <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                            <td><?= $order['items'] ?>件</td>
                            <td><?= $order['payment_method'] ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>