<?php
session_start();
require '../config.php';

// 获取当前门店仓库信息
$store_id = isset($_SESSION['store_id']) ? $_SESSION['store_id'] : 0;
if (!$store_id) {
    throw new Exception("未设置门店ID");
}

$warehouse_stmt = $pdo->prepare("SELECT warehouse_id FROM store WHERE store_id = ?");
$warehouse_stmt->execute([$store_id]);
$warehouse_id = $warehouse_stmt->fetchColumn();

// 初始化变量
$error = '';
$success = '';

// 表单处理
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $pdo->beginTransaction();

        // 处理客户信息更新
        if (isset($_POST['update_customer'])) {
            $update_stmt = $pdo->prepare("
                UPDATE customer SET 
                    credit_limit = ?,
                    membership_level = ?
                WHERE customer_id = ?
            ");
            $update_stmt->execute([
                $_POST['credit_limit'],
                $_POST['membership_level'],
                $_POST['customer_id']
            ]);
            $success = '客户信息更新成功';
        }

        // 处理新订单创建
        if (isset($_POST['create_order'])) {
            // 验证客户信息
            $customer_stmt = $pdo->prepare("
                SELECT *, 
                    (credit_limit - IFNULL((
                        SELECT SUM(amount) 
                        FROM financial_transaction 
                        WHERE customer_id = c.customer_id 
                        AND transaction_type = '应收款'
                    ), 0)) AS available_credit
                FROM customer c
                WHERE customer_id = ?
            ");
            $customer_stmt->execute([$_POST['customer_id']]);
            $customer = $customer_stmt->fetch();

            if (!$customer) {
                throw new Exception("无效的客户信息");
            }

            // 计算折扣率（每会员等级5%折扣）
            $discount_rate = 1 - ($customer['membership_level'] * 0.05);

            // 创建销售订单
            $order_no = 'WS' . date('YmdHis');
            $order_stmt = $pdo->prepare("
                INSERT INTO sales_order 
                (order_no, customer_id, total_amount, payment_method, order_type, salesperson_id, store_id)
                VALUES (?, ?, ?, '赊账', '批发', ?, ?)
            ");
            $order_stmt->execute([
                $order_no,
                $customer['customer_id'],
                0,  // 初始总金额
                $_SESSION['user_id'],
                $store_id
            ]);
            $order_id = $pdo->lastInsertId();

            // 处理订单商品
            $total_amount = 0;
            foreach ($_POST['products'] as $product_id => $quantity) {
                $quantity = (int)$quantity;
                if ($quantity > 0) {
                    // 验证库存
                    $product_stmt = $pdo->prepare("
                        SELECT p.unit_price, i.quantity AS stock
                        FROM products p
                        JOIN inventory i USING(product_id)
                        WHERE p.product_id = ? AND i.warehouse_id = ?
                    ");
                    $product_stmt->execute([$product_id, $warehouse_id]);
                    $product = $product_stmt->fetch();

                    if (!$product || $product['stock'] < $quantity) {
                        throw new Exception("商品库存不足: ID{$product_id}");
                    }

                    // 计算价格
                    $price = $product['unit_price'] * $discount_rate;
                    $subtotal = $price * $quantity;

                    // 插入订单明细
                    $item_stmt = $pdo->prepare("
                        INSERT INTO order_item 
                        (order_id, product_id, quantity, unit_price, batch_no)
                        VALUES (?, ?, ?, ?, (
                            SELECT batch_no 
                            FROM inventory 
                            WHERE product_id = ? 
                            ORDER BY expiry_date ASC 
                            LIMIT 1
                        ))
                    ");
                    $item_stmt->execute([
                        $order_id,
                        $product_id,
                        $quantity,
                        $price,
                        $product_id
                    ]);

                    $total_amount += $subtotal;
                }
            }

            // 更新订单总金额
            $update_order_stmt = $pdo->prepare("
                UPDATE sales_order 
                SET total_amount = ?
                WHERE order_id = ?
            ");
            $update_order_stmt->execute([$total_amount, $order_id]);

            // 检查信用额度
            if ($total_amount > $customer['available_credit']) {
                throw new Exception("超出可用信用额度");
            }

            // 记录应收款
            $finance_stmt = $pdo->prepare("
                INSERT INTO financial_transaction 
                (order_id, amount, transaction_type, transaction_time)
                VALUES (?, ?, '应收款', NOW())
            ");
            $finance_stmt->execute([
                $order_id,
                $total_amount
            ]);

            $success = '订单创建成功，订单号: ' . $order_no;
        }

        $pdo->commit();
    } catch (Exception $e) {
        $pdo->rollBack();
        $error = $e->getMessage();
    }
}

// 获取数据
$customers = $pdo->query("
    SELECT c.*, 
        IFNULL((
            SELECT SUM(amount) 
            FROM financial_transaction 
            WHERE customer_id = c.customer_id 
            AND transaction_type = '应收款'
        ), 0) AS receivable
    FROM customer c
    WHERE c.customer_type = '批发客户'
    ORDER BY c.customer_name
")->fetchAll();

$stmt = $pdo->prepare("
    SELECT p.*, i.quantity AS stock
    FROM products p
    JOIN inventory i USING(product_id)
    WHERE i.warehouse_id = ?
");
$stmt->execute([$warehouse_id]);
$products = $stmt->fetchAll();

// 获取应收款数据
$receivables = $pdo->query("
    SELECT c.customer_name, f.amount, f.transaction_time,
        DATEDIFF(NOW(), f.transaction_time) AS days_passed
    FROM financial_transaction f
    JOIN sales_order s ON f.order_id = s.order_id
    JOIN customer c ON s.customer_id = c.customer_id
    WHERE f.transaction_type = '应收款'
    HAVING days_passed > 30
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>批发销售管理</title>
    <style>
        /* 基础样式 */
        body {
            font-family: Arial, sans-serif;
            background: #f8f9fa;
            margin: 0;
        }

        .container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 0 15px;
        }

        /* 模块标题 */
        .section-title {
            border-left: 4px solid #3498db;
            padding-left: 12px;
            margin: 40px 0 20px;
            color: #2c3e50;
        }

        /* 客户卡片 */
        .customer-card {
            background: white;
            border: 1px solid #e9ecef;
            border-radius: 6px;
            padding: 20px;
            margin-bottom: 15px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
        }

        .credit-bar {
            height: 8px;
            background: #e9ecef;
            border-radius: 4px;
            margin: 10px 0;
            overflow: hidden;
        }

        .credit-used {
            height: 100%;
            background: #3498db;
            transition: width 0.3s ease;
        }

        /* 商品选择 */
        .product-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
            gap: 15px;
            margin: 20px 0;
        }

        .product-item {
            border: 1px solid #dee2e6;
            padding: 15px;
            border-radius: 6px;
            background: white;
        }

        .stock-info {
            color: #6c757d;
            font-size: 0.9em;
            margin-top: 8px;
        }

        /* 应收款提醒 */
        .receivable-alert {
            background: #fff3cd;
            border: 1px solid #ffeeba;
            border-radius: 6px;
            padding: 20px;
            margin: 25px 0;
        }

        .overdue-tag {
            background: #dc3545;
            color: white;
            padding: 3px 8px;
            border-radius: 12px;
            font-size: 0.85em;
        }

        /* 表单元素 */
        select,
        input[type="number"] {
            width: 100%;
            padding: 8px 12px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            margin: 5px 0;
        }

        .btn-primary {
            background: #3498db;
            color: white;
            padding: 10px 25px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 15px;
        }
    </style>
</head>

<body>
    <div class="container">
        <!-- 客户管理 -->
        <h2 class="section-title">批发客户管理</h2>
        <?php foreach ($customers as $c): ?>
            <div class="customer-card">
                <form method="post">
                    <h3 style="margin-top:0"><?= htmlspecialchars($c['customer_name']) ?></h3>

                    <div class="form-group">
                        <label>信用额度（元）</label>
                        <input type="number" name="credit_limit"
                            value="<?= $c['credit_limit'] ?>" step="500" required>
                    </div>

                    <div class="form-group">
                        <label>折扣等级</label>
                        <select name="membership_level" required>
                            <?php for ($i = 1; $i <= 5; $i++): ?>
                                <option value="<?= $i ?>" <?= $i == $c['membership_level'] ? 'selected' : '' ?>>
                                    等级 <?= $i ?> - <?= 100 - $i * 5 ?>折
                                </option>
                            <?php endfor; ?>
                        </select>
                    </div>

                    <div class="credit-info">
                        <div style="display:flex; justify-content:space-between">
                            <span>已用额度：¥<?= number_format($c['receivable'], 2) ?></span>
                            <span>剩余额度：¥<?= number_format($c['credit_limit'] - $c['receivable'], 2) ?></span>
                        </div>

                        <div class="credit-bar">
                            <div class="credit-used" style="width: <?= ($c['receivable'] / $c['credit_limit']) * 100 ?>%;"></div>
                        </div>
                    </div>

                    <input type="hidden" name="customer_id" value="<?= $c['customer_id'] ?>">
                    <button type="submit" name="update_customer" class="btn-primary">
                        更新客户信息
                    </button>
                </form>
            </div>
        <?php endforeach; ?>

        <!-- 订单创建 -->
        <h2 class="section-title">创建批发订单</h2>
        <?php if (isset($error)): ?>
            <div style="color:#dc3545; padding:15px; background:#f8d7da; border-radius:4px; margin:15px 0">
                <?= htmlspecialchars($error) ?>
            </div>
        <?php endif; ?>
        <?php if (isset($success)): ?>
            <div style="color:#155724; padding:15px; background:#d4edda; border-radius:4px; margin:15px 0">
                <?= htmlspecialchars($success) ?>
            </div>
        <?php endif; ?>

        <form method="post">
            <div style="margin:20px 0">
                <label>选择客户：</label>
                <select name="customer_id" required>
                    <?php foreach ($customers as $c): ?>
                        <option value="<?= $c['customer_id'] ?>">
                            <?= htmlspecialchars($c['customer_name']) ?>
                            (可用额度：¥<?= number_format($c['credit_limit'] - $c['receivable'], 2) ?>)
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="product-grid">
                <?php foreach ($products as $p): ?>
                    <div class="product-item">
                        <label style="font-weight:500"><?= htmlspecialchars($p['model']) ?></label>
                        <input type="number" name="products[<?= $p['product_id'] ?>]"
                            min="0" max="<?= $p['stock'] ?>"
                            placeholder="请输入数量"
                            style="margin:10px 0">
                        <div class="stock-info">
                            库存 <?= $p['stock'] ?> 件｜单价 ¥<?= $p['unit_price'] ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

            <button type="submit" name="create_order" class="btn-primary">
                提交批发订单
            </button>
        </form>

        <!-- 应收款提醒 -->
        <h2 class="section-title">应收款提醒</h2>
        <div class="receivable-alert">
            <?php if (count($receivables) > 0): ?>
                <?php foreach ($receivables as $r): ?>
                    <div style="margin:15px 0; padding:15px; background:<?= $r['days_passed'] > 60 ? '#f8d7da' : '#fff3cd' ?>; border-radius:4px">
                        <div style="display:flex; justify-content:space-between; align-items:center">
                            <h4 style="margin:0"><?= htmlspecialchars($r['customer_name']) ?></h4>
                            <span class="overdue-tag">逾期 <?= $r['days_passed'] ?> 天</span>
                        </div>
                        <div style="margin-top:10px">
                            <div>金额：¥<?= number_format($r['amount'], 2) ?></div>
                            <div style="color:#6c757d; font-size:0.9em">
                                生成时间：<?= date('Y-m-d H:i', strtotime($r['transaction_time'])) ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php else: ?>
                <div style="text-align:center; color:#6c757d; padding:20px">
                    当前没有逾期应收款
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>