<?php
session_start();
require '../config.php';

$error = '';
$success = '';
$user = [];
$stores = [];

// 获取用户信息
if (isset($_GET['id'])) {
    $user_id = (int)$_GET['id'];
    $stmt = $pdo->prepare("
        SELECT * FROM system_user 
        WHERE user_id = ?
    ");
    $stmt->execute([$user_id]);
    $user = $stmt->fetch();

    if (!$user) {
        $error = "用户不存在";
    }
}

// 获取所有门店
$stores = $pdo->query("SELECT store_id, store_name FROM store")->fetchAll();

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST' && $user) {
    $username = trim($_POST['username']);
    $role = $_POST['role'];
    $store_id = $_POST['store_id'] ?? null;

    try {
        // 验证用户名格式
        if (!preg_match('/^[a-zA-Z0-9_]{3,20}$/', $username)) {
            throw new Exception("用户名格式错误（3-20位字母、数字或下划线）");
        }

        // 验证角色有效性
        $allowed_roles = ['admin', 'store_manager', 'sales', 'finance', 'logistics'];
        if (!in_array($role, $allowed_roles)) {
            throw new Exception("无效的角色类型");
        }

        // 验证门店关联
        if ($role === 'store_manager' && empty($store_id)) {
            throw new Exception("门店管理员必须关联到具体门店");
        }

        // 更新用户信息
        $stmt = $pdo->prepare("
            UPDATE system_user 
            SET username = ?, role = ?, store_id = ?
            WHERE user_id = ?
        ");
        $stmt->execute([
            $username,
            $role,
            $role === 'store_manager' ? $store_id : null,
            $user['user_id']
        ]);

        $_SESSION['success'] = "用户信息更新成功";
        header("Location: user_management.php");
        exit;
    } catch (PDOException $e) {
        $error = "操作失败：" . ($e->getCode() == 23000 ? '用户名已存在' : $e->getMessage());
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}
?>
<!DOCTYPE html>
<html>

<head>
    <title>编辑用户</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 确保选择框宽度适配 */
        .full-width {
            width: 100%;
            padding: 8px;
            box-sizing: border-box;
        }

        /* 强化必填项标识 */
        select:required {
            border-left: 3px solid #dc3545;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>编辑用户</h2>

        <?php if ($error): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <?php if ($user): ?>
            <div class="card">
                <form method="POST">
                    <div class="form-group">
                        <label>用户名</label>
                        <input type="text" name="username"
                            value="<?= htmlspecialchars($user['username']) ?>"
                            pattern="[a-zA-Z0-9_]{3,20}"
                            required>
                    </div>

                    <div class="form-group">
                        <label>角色</label>
                        <select name="role" id="roleSelect" required>
                            <option value="admin" <?= $user['role'] === 'admin' ? 'selected' : '' ?>>管理员</option>
                            <option value="store_manager" <?= $user['role'] === 'store_manager' ? 'selected' : '' ?>>店长</option>
                            <option value="sales" <?= $user['role'] === 'sales' ? 'selected' : '' ?>>销售</option>
                            <option value="finance" <?= $user['role'] === 'finance' ? 'selected' : '' ?>>财务</option>
                            <option value="logistics" <?= $user['role'] === 'logistics' ? 'selected' : '' ?>>物流</option>
                        </select>
                    </div>

                    <!-- 门店选择字段（修复显示逻辑） -->
                    <div class="form-group" id="storeField"
                        style="display: <?= in_array($user['role'], ['admin', 'store_manager']) ? 'block' : 'none' ?>;">
                        <label>关联门店</label>
                        <select name="store_id" class="full-width">
                            <option value="">-- 请选择门店 --</option>
                            <?php foreach ($stores as $store): ?>
                                <option value="<?= $store['store_id'] ?>"
                                    <?= $store['store_id'] == $user['store_id'] ? 'selected' : '' ?>>
                                    <?= htmlspecialchars($store['store_name']) ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-footer">
                        <button type="submit" class="btn-primary">保存更改</button>
                        <a href="user_management.php" class="btn-cancel">取消</a>
                    </div>
                </form>
            </div>
        <?php else: ?>
            <div class="alert alert-error"><?= $error ?: '用户不存在' ?></div>
        <?php endif; ?>
    </div>

    <script>
        // 修改角色监听逻辑
        document.addEventListener('DOMContentLoaded', function() {
            const roleSelect = document.getElementById('roleSelect');
            const storeField = document.getElementById('storeField');
            const storeSelect = storeField.querySelector('select');

            const updateStoreField = () => {
                const showStore = ['admin', 'store_manager'].includes(roleSelect.value);
                storeField.style.display = showStore ? 'block' : 'none';
                storeSelect.required = showStore;
            };

            roleSelect.addEventListener('change', updateStoreField);
            updateStoreField(); // 初始化状态
        });
    </script>
</body>

</html>